# Changelog
All notable changes to this project will be documented in this file.

## [v1.1.1]
### Fixed
- Readme.md and pypi package description

## [v1.1.0]
### Added
- Static maps api


## [v1.0.0]
### Added
- Initial version

